@@ -49,7 +49,7 @@ def delete_old_disk_caches():
     n_deleted = 0
     deleted_caches = []
     for file in get_files_in_directory(disk_cache_dir):
-        max_age_days = int(file.split('_')[-1].replace('.pkl', ''))
+        max_age_days = int(file.split('****')[-1].replace('.pkl', ''))
         if get_age_of_file(disk_cache_dir + file) > max_age_days:
             os.remove(disk_cache_dir + file)
             deleted_caches.append(file)
